Changelog
=========

0.2.2
-----
    - Small bugfix.
    - Removed unused files.

0.2.1
-----
    - Switched to complete randomly generated ZEO environment (random name in /tmp, and random ports for ZEO server process).

0.2.0
-----
    - Bugfix of path parsing.

0.1.0
-----
    - Project created.
